==> fortunes-it_2.16.orig.tar.gz: fortunes-it/CHANGELOG.md <==
2.16
====
* Citazioni di Leonardo Sciascia da "Gli zii di Sicilia"
* Citazioni di Alessandro Barbero
* Rimossa cosa rimasta di Ezra Pound
* Citazione mia

2.15
====
* Battute da lercio
* Citazioni
* Rimosse cose brutte
* Spostate cose offensive
* Rimosse cose in lingua straniera

2.14
====
* Rimosse battute vetuste
* Aggiunte citazioni
* Aggiunta battuta su musk

2.13
====
* Correggere i file senza simbolo % finale
* Spostare cose innocenti fuori da -o
* Battute da lercio

2.12
====
* Citazioni di Karl Marx
* Battute da lercio
* Citazione di Winston Churchill
* Rimosse battute politiche vetuste

2.11
====
* Battute da nonciclopedia
* Battute da lercio
* Citazione di Barbero
* Citazioni da Boris
* Citazioni da BardoMagno
* Aggiunta qualche firma nelle citazioni da lercio

2.10
====
* Lercio
* Rimosso duplicato
* Spostate cose offensive

2.9
===
* Citazioni
* Correzioni
* EELST
* Rimosse cose sessiste e non divertenti
* Spostate cose in milanese nella sezione brianza così non le vedo più

2.8
===
* Aggiunte battute
* EELST
* Rimosse battute insensate
* Spostate battute offensive

2.7
===
* Citazioni di Checco Zalone
* Citazioni di Camilleri
* Rimosse un po' di cose insulse
* Spostate cose offensive
* Aggiunta sezione Lercio!

2.6
===
* Spostate cose sessiste in -o
* Aggiunte citazioni politiche più recenti
* Aggiunta citazione di Oscar Wilde
* Rimosso Ezra Pound
* Rimuovere cose insulse di woody allen, sono troppe
* Corretta battuta
* Citazioni di Camilleri

2.5
===
* Battute pessime
* Citazione di Russel
* Proverbio siciliano

2.4
===

* Correzioni
* Aggiunte cose
* Tolte cose in inglese
* Spostate alcune cose sessiste in -o
* Aggiornato readme

2.3
===

* Correzioni
* Spostata cosa in -o

2.2
===

* Aggiunti fortunes in siciliano
* Aggiunta qualche battuta
* Piccole correzioni
* Spostate un pacco di cose sessiste in -o

2.1
===

* Aggiunti nuovi fortunes!

2.0
===

* Spostati i proverbi della Brianza in un file a parte
* Fork e prima release
* Spostate cose offensive nelle sezioni offensive
* Importate le patch da Debian
* Riscritti i Makefile per essere più standard

==> fortunes-it_2.17.orig.tar.gz: fortunes-it/CHANGELOG.md <==
2.17
====
* Barbero sui Longobardi
* Citazione corretta
* Rimosse cose brutte
* Battute da lercio
* Siciliano
* Citazioni simpatichette dalla Bibbia, messe in -o per sicurezza
* Citazioni di Churchill che andavano in -o senza alcun dubbio
* Rimosso per intero Jack Frusciante è uscito dal gruppo
  (mai piaciuto)
* Grande censura dei fortunes offensivi
* Spostate cose non offensive nella sezione normale
* Aggiunto codice di condotta

2.16
====
* Citazioni di Leonardo Sciascia da "Gli zii di Sicilia"
* Citazioni di Alessandro Barbero
* Rimossa cosa rimasta di Ezra Pound
* Citazione mia

2.15
====
* Battute da lercio
* Citazioni
* Rimosse cose brutte
* Spostate cose offensive
* Rimosse cose in lingua straniera

2.14
====
* Rimosse battute vetuste
* Aggiunte citazioni
* Aggiunta battuta su musk

2.13
====
* Correggere i file senza simbolo % finale
* Spostare cose innocenti fuori da -o
* Battute da lercio

2.12
====
* Citazioni di Karl Marx
* Battute da lercio
* Citazione di Winston Churchill
* Rimosse battute politiche vetuste

2.11
====
* Battute da nonciclopedia
* Battute da lercio
* Citazione di Barbero
* Citazioni da Boris
* Citazioni da BardoMagno
* Aggiunta qualche firma nelle citazioni da lercio

2.10
====
* Lercio
* Rimosso duplicato
* Spostate cose offensive

2.9
===
* Citazioni
* Correzioni
* EELST
* Rimosse cose sessiste e non divertenti
* Spostate cose in milanese nella sezione brianza così non le vedo più

2.8
===
* Aggiunte battute
* EELST
* Rimosse battute insensate
* Spostate battute offensive

2.7
===
* Citazioni di Checco Zalone
* Citazioni di Camilleri
* Rimosse un po' di cose insulse
* Spostate cose offensive
* Aggiunta sezione Lercio!

2.6
===
* Spostate cose sessiste in -o
* Aggiunte citazioni politiche più recenti
* Aggiunta citazione di Oscar Wilde
* Rimosso Ezra Pound
* Rimuovere cose insulse di woody allen, sono troppe
* Corretta battuta
* Citazioni di Camilleri

2.5
===
* Battute pessime
* Citazione di Russel
* Proverbio siciliano

2.4
===

* Correzioni
* Aggiunte cose
* Tolte cose in inglese
* Spostate alcune cose sessiste in -o
* Aggiornato readme

2.3
===

* Correzioni
* Spostata cosa in -o

2.2
===

* Aggiunti fortunes in siciliano
* Aggiunta qualche battuta
* Piccole correzioni
* Spostate un pacco di cose sessiste in -o

2.1
===

* Aggiunti nuovi fortunes!

2.0
===

* Spostati i proverbi della Brianza in un file a parte
* Fork e prima release
* Spostate cose offensive nelle sezioni offensive
* Importate le patch da Debian
* Riscritti i Makefile per essere più standard
